import 'package:graphql/client.dart';

import 'custom_exception.dart';

String token = '';

class GraphQLProvider {
  final HttpLink _httpLink = HttpLink("https://api-dev.fasekyc.com/graphql");
  AuthLink _authLink = AuthLink(getToken: () async => 'Bearer $token');

  late GraphQLClient client;
  GraphQLProvider({String token = ""}) {
    _authLink = AuthLink(getToken: () async => 'Bearer $token');
    client = GraphQLClient(
      cache: GraphQLCache(),
      link: _authLink.concat(_httpLink),
    );
  }

  Future<dynamic> send(String query,
      {Map<String, dynamic>? variables, FetchPolicy? fetchPolicy}) async {
    print("query: $query");
    print("variables: $variables");
    final QueryOptions options = QueryOptions(
      document: gql(query),
      fetchPolicy: fetchPolicy ?? FetchPolicy.networkOnly,
      variables: variables == null ? {} : variables,
    );
    try {
      QueryResult result = await this.client.query(options);
      if (result.hasException) {
        if (result.exception?.linkException != null) {
          throw CustomException(
              result.exception?.linkException?.originalException);
        }
        if (result.exception?.graphqlErrors != null) {
          print("Server Error: ${result.exception?.graphqlErrors}");
          throw CustomException(result.exception?.graphqlErrors[0].message);
        }
      } else {
        var data = result.data;
        print("Data from GraphQL: $data");
        return data;
      }
    } catch (e) {
      print("Error GraphQL: $e");
      throw CustomException(e);
    }
  }
}
