import 'dart:async';
import 'package:fasekyc_flutter/src/model/my_oauth2_client.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:oauth2_client/authorization_response.dart';
import 'package:http/http.dart' as http;

class FaSeKYCAuthButton extends StatefulWidget {
  final ValueChanged<bool> onSuccess;
  final ValueChanged<String> onUserCancel;
  final String clientId;
  final String clientSecret;
  final String redirectUri;
  final String customUriScheme;
  final List<String>? scopes;
  final Widget? child;
  final String? authUrl;
  final String personId;
  final Color? backgroundColor;

  FaSeKYCAuthButton({
    Key? key,
    required this.onSuccess,
    required this.clientId,
    required this.clientSecret,
    required this.redirectUri,
    required this.customUriScheme,
    required this.onUserCancel,
    required this.personId,
    this.authUrl,
    this.scopes,
    this.child,
    this.backgroundColor,
  }) : super(key: key);

  @override
  _LoginButtonState createState() => _LoginButtonState();
}

class _LoginButtonState extends State<FaSeKYCAuthButton> {
  MyOAuth2Client? myOAuth2Client;
  StreamController<bool>? isLoadingBtn = StreamController<bool>();
  List<String> _scopes = ["email", "openid"];

  @override
  void initState() {
    myOAuth2Client = MyOAuth2Client(
      redirectUri: widget.redirectUri,
      customUriScheme: widget.customUriScheme,
      tokenUrl: 'https://api-dev.fasekyc.com/oauth2/token',
      authorizeUrl: "https://app-dev.fasekyc.com/authenticate",
    );
    super.initState();
  }

  @override
  void dispose() {
    isLoadingBtn?.close();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return ElevatedButton(
      style: ButtonStyle(
        backgroundColor: MaterialStateProperty.all(
            widget.backgroundColor ?? Color(0xFF114CFE)),
        elevation: MaterialStateProperty.all(0.0),
      ),
      onPressed: () {
        requestingOauth2();
      },
      child: widget.child == null
          ? Text(
              'បើក​គណនីជាមួយ' + "Fas" + " " + "eKYC",
              style: TextStyle(
                color: Colors.white,
                fontFamily: 'khFont',
                fontSize: 16.0,
              ),
            )
          : widget.child,
    );
  }

  requestingOauth2() async {
    try {
      var refreshUrl = myOAuth2Client!.refreshUrl;
      print("refreshUrl: $refreshUrl");
      var authorizeUrl = myOAuth2Client!.authorizeUrl;
      print("authorizeUrl: $authorizeUrl");
      var tokenUrl = myOAuth2Client!.tokenUrl;
      print("tokenUrl: $tokenUrl");

      AuthorizationResponse response = await myOAuth2Client!
          .requestAuthorization(
              clientId: widget.clientId,
              scopes: widget.scopes,
              customParams: {
            "person_id": widget.personId,
          });
      print('response: $response');
      String? accessToken = response.code;
      var url = Uri.parse('https://api-dev.fasekyc.com/check-ticket');
      var res = await http.post(url, body: {'ticket_id': accessToken});
      var isSuccess = res.body == 'true';
      widget.onSuccess(isSuccess);
    } on PlatformException catch (e) {
      var message = e.toString();
      if (e.code == 'CANCELED') {
        message = "អ្នកបានធ្វើការបោះបង់ចោល ប្រតិបត្តិការនេះ។";
      } else {
        message = e.message.toString();
      }
      widget.onUserCancel(message);
    } catch (e) {
      var message = e.toString();
      widget.onUserCancel(message);
    }
  }
}
