import 'dart:async';
import 'package:fasekyc_flutter/src/api/person.dart';
import 'package:fasekyc_flutter/src/model/my_oauth2_client.dart';
import 'package:fasekyc_flutter/src/model/person.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:oauth2_client/access_token_response.dart';
import 'package:oauth2_client/oauth2_client.dart';

class FaSeKYCButton extends StatefulWidget {
  final ValueChanged<PersonModel> onSuccess;
  final ValueChanged<String> onUserCancel;
  final String clientId;
  final String clientSecret;
  final String redirectUri;
  final String customUriScheme;
  final List<String>? scopes;
  final Widget? child;
  final String? authUrl;
  final Color? backgroundColor;

  FaSeKYCButton({
    Key? key,
    required this.onSuccess,
    required this.clientId,
    required this.clientSecret,
    required this.redirectUri,
    required this.customUriScheme,
    required this.onUserCancel,
    this.authUrl,
    this.scopes,
    this.child,
    this.backgroundColor,
  }) : super(key: key);

  @override
  _LoginButtonState createState() => _LoginButtonState();
}

class _LoginButtonState extends State<FaSeKYCButton> {
  MyOAuth2Client? myOAuth2Client;
  StreamController<bool>? isLoadingBtn = StreamController<bool>();
  List<String> _scopes = ["email", "openid"];

  @override
  void initState() {
    myOAuth2Client = MyOAuth2Client(
      redirectUri: widget.redirectUri,
      customUriScheme: widget.customUriScheme,
      tokenUrl: 'https://api-dev.fasekyc.com/oauth2/token',
      authorizeUrl: widget.authUrl ?? "https://app-dev.fasekyc.com/authorize",
    );
    super.initState();
  }

  @override
  void dispose() {
    isLoadingBtn?.close();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return ElevatedButton(
      style: ButtonStyle(
        backgroundColor: MaterialStateProperty.all(
            widget.backgroundColor ?? Color(0xFF114CFE)),
        elevation: MaterialStateProperty.all(0.0),
      ),
      onPressed: () {
        requestingOauth2();
      },
      child: widget.child == null
          ? Text(
              'បើក​គណនីជាមួយ' + "Fas" + " " + "eKYC",
              style: TextStyle(
                color: Colors.white,
                fontFamily: 'khFont',
                fontSize: 16.0,
              ),
            )
          : widget.child,
    );
  }

  requestingOauth2() async {
    try {
      var refreshUrl = myOAuth2Client!.refreshUrl;
      print("refreshUrl: $refreshUrl");
      var authorizeUrl = myOAuth2Client!.authorizeUrl;
      print("authorizeUrl: $authorizeUrl");
      var tokenUrl = myOAuth2Client!.tokenUrl;
      print("tokenUrl: $tokenUrl");

      AccessTokenResponse tknResp =
          await myOAuth2Client!.getTokenWithAuthCodeFlow(
        clientId: widget.clientId,
        scopes: widget.scopes ?? _scopes,
        clientSecret: widget.clientSecret,
        accessTokenParams: {
          'client_secret': widget.clientSecret,
          'client_id': widget.clientId,
        },
      );
      String? accessToken = tknResp.accessToken;
      if (accessToken != null) {
        final result = await personInfoAPI.getPersonInfo("", accessToken);
        widget.onSuccess(result);
      }
    } on PlatformException catch (e) {
      var message = e.toString();
      if (e.code == 'CANCELED') {
        message = "អ្នកបានធ្វើការបោះបង់ចោល ប្រតិបត្តិការនេះ។";
      } else {
        message = e.message.toString();
      }
      widget.onUserCancel(message);
    } catch (e) {
      var message = e.toString();
      widget.onUserCancel(message);
    }
  }
}
